@@ -14,7 +14,7 @@
 // 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
+//Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 //
 //
 
@@ -315,6 +315,8 @@ namespace LongoMatch.Gui
 			bool visible = ((Gtk.ToggleAction)sender).Active;
 			playlistwidget2.Visible=visible;
 			treewidget1.PlayListLoaded=visible;
+			localplayerslisttreewidget.PlayListLoaded=visible;
+			visitorplayerslisttreewidget.PlayListLoaded=visible;
 			
 			if (!visible && !noteswidget1.Visible){
 				rightvbox.Visible = false;
